Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(61)

Unified Diff: ios/chrome/browser/payments/shipping_address_selection_view_controller_unittest.mm

Issue 2712053003: [Payment Request] Displays Contact Info in the payment summary view (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/chrome/browser/payments/shipping_address_selection_view_controller_unittest.mm
diff --git a/ios/chrome/browser/payments/shipping_address_selection_view_controller_unittest.mm b/ios/chrome/browser/payments/shipping_address_selection_view_controller_unittest.mm
index d386384d5a1ccfb0e94a869ce5040185099d5c4f..524cddc9a6530710babf5151e01bdefc8b8f9f2e 100644
--- a/ios/chrome/browser/payments/shipping_address_selection_view_controller_unittest.mm
+++ b/ios/chrome/browser/payments/shipping_address_selection_view_controller_unittest.mm
@@ -9,8 +9,8 @@
#include "components/autofill/core/browser/autofill_profile.h"
#include "components/autofill/core/browser/test_personal_data_manager.h"
#include "components/strings/grit/components_strings.h"
+#import "ios/chrome/browser/payments/cells/autofill_profile_item.h"
#import "ios/chrome/browser/payments/cells/payments_text_item.h"
-#import "ios/chrome/browser/payments/cells/shipping_address_item.h"
#include "ios/chrome/browser/payments/payment_request.h"
#include "ios/chrome/browser/payments/payment_request_test_util.h"
#import "ios/chrome/browser/ui/autofill/cells/status_item.h"
@@ -76,16 +76,16 @@ TEST_F(ShippingAddressSelectionViewControllerTest, TestModel) {
id item = GetCollectionViewItem(0, 0);
EXPECT_TRUE([item isMemberOfClass:[PaymentsTextItem class]]);
// The next two items should be of type ShippingAddressItem. The first one
// should appear to be selected.
item = GetCollectionViewItem(0, 1);
- ASSERT_TRUE([item isMemberOfClass:[ShippingAddressItem class]]);
- ShippingAddressItem* shipping_address_item = item;
+ ASSERT_TRUE([item isMemberOfClass:[AutofillProfileItem class]]);
+ AutofillProfileItem* shipping_address_item = item;
EXPECT_EQ(MDCCollectionViewCellAccessoryCheckmark,
shipping_address_item.accessoryType);
item = GetCollectionViewItem(0, 2);
- EXPECT_TRUE([item isMemberOfClass:[ShippingAddressItem class]]);
+ EXPECT_TRUE([item isMemberOfClass:[AutofillProfileItem class]]);
shipping_address_item = item;
EXPECT_EQ(MDCCollectionViewCellAccessoryNone,
shipping_address_item.accessoryType);
@@ -76,16 +76,16 @@ TEST_F(ShippingAddressSelectionViewControllerTest, TestModel) {
id item = GetCollectionViewItem(0, 0);
EXPECT_TRUE([item isMemberOfClass:[PaymentsTextItem class]]);
- // The next two items should be of type ShippingAddressItem. The first one
+ // The next two items should be of type AutofillProfileItem. The first one
// should appear to be selected.
item = GetCollectionViewItem(0, 1);

Powered by Google App Engine
This is Rietveld 408576698